@@ -18,6 +18,8 @@ class CurrentCPs(AppConfig):
 		self.widget = None
 		self.player_cps = []  # Holds the sorted PlayerCP objects (these get displayed by the widget)
 
+		self.dedimania_enabled = False
+
 	# FOR TESTING ONLY, DO NOT USE IN PRODUCTION CODE
 	def fill_test_cps(self):
 		"""
@@ -51,13 +53,15 @@ class CurrentCPs(AppConfig):
 		self.context.signals.listen(tm_signals.finish, self.player_finish)
 		self.context.signals.listen(mp_signals.player.player_connect, self.player_connect)
 		self.context.signals.listen(mp_signals.player.player_disconnect, self.player_disconnect)
-		self.context.signals.listen(mp_signals.map.map_start__end, self.map_end)
+		self.context.signals.listen(mp_signals.map.map_start__end, self.map_start)
 		self.context.signals.listen(mp_signals.player.player_enter_spectator_slot, self.player_enter_spec)
 
 		# Make sure we move the rounds_scores and other gui elements.
-		self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 87. 150.')
+		self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 80. 150.')
 		self.instance.ui_manager.properties.set_attribute('multilap_info', 'pos', '107., 88., 5.')
 
+		self.dedimania_enabled = ('dedimania' in self.instance.apps.apps and 'dedimania' not in self.instance.apps.unloaded_apps)
+
 		self.widget = CPWidgetView(self)
 		# await self.widget.display()
 		await self.update_view()
@@ -110,8 +114,9 @@ class CurrentCPs(AppConfig):
 		self.current_cps.pop(player.login, None)
 		await self.update_view()
 
-	# When the map ends
-	async def map_end(self, *args, **kwargs):
+	# When the map start (end of event)
+	async def map_start(self, *args, **kwargs):
+		self.dedimania_enabled = ('dedimania' in self.instance.apps.apps and 'dedimania' not in self.instance.apps.unloaded_apps)
 		self.current_cps.clear()  # Clear the current CPs when the map ends
 		await self.update_view()
 
