@@ -40,22 +40,27 @@ class MX(AppConfig):  # pragma: no cover
 		)
 
 		await self.instance.command_manager.register(
-			Command(command='info', namespace='mx', target=self.mx_info),
+			Command(command='info', namespace='mx', target=self.mx_info,
+					description='Display ManiaExchange information for current map.'),
 			# support backwards
-			Command(command='mx', namespace='add', target=self.add_mx_map, perms='mx:add_remote', admin=True).add_param(
+			Command(command='mx', namespace='add', target=self.add_mx_map, perms='mx:add_remote', admin=True,
+					description='Add map from ManiaExchange to the maplist.').add_param(
 				'maps', nargs='*', type=str, required=True, help='MX ID(s) of maps to add.'),
 
 			# new mx namespace
 			Command(command='search', aliases=['list'], namespace='mx', target=self.search_mx_map, perms='mx:add_remote',
-					admin=True),
-			Command(command='add', namespace='mx', target=self.add_mx_map, perms='mx:add_remote', admin=True).add_param(
+					admin=True, description='Search for maps on ManiaExchange.'),
+			Command(command='add', namespace='mx', target=self.add_mx_map, perms='mx:add_remote', admin=True,
+					description='Add map from ManiaExchange to the maplist.').add_param(
 				'maps', nargs='*', type=str, required=True, help='MX ID(s) of maps to add.'),
-			Command(command='status', namespace='mx', target=self.status_mx_maps, perms='mx:add_remote', admin=True),
+			Command(command='status', namespace='mx', target=self.status_mx_maps, perms='mx:add_remote', admin=True,
+					description='View the map statuses compared to ManiaExchange.'),
 
 			# new mxpack namespace
 			Command(command='search', aliases=['list'], namespace='mxpack', target=self.search_mx_pack,
-					perms='mx:add_remote', admin=True),
-			Command(command='add', namespace='mxpack', target=self.add_mx_pack, perms='mx:add_remote', admin=True)
+					perms='mx:add_remote', admin=True, description='Search for mappacks on ManiaExchange.'),
+			Command(command='add', namespace='mxpack', target=self.add_mx_pack, perms='mx:add_remote', admin=True,
+					description='Add mappack from ManiaExchange to the maplist.')
 				.add_param('pack', nargs='*', type=str, required=True, help='MX ID(s) of mappacks to add.'),
 		)
 
@@ -161,7 +166,7 @@ class MX(AppConfig):  # pragma: no cover
 		juke_maps = await juke_after_adding.get_value()
 		if 'jukebox' not in self.instance.apps.apps:
 			juke_maps = False
-		juke_list = list()
+		added_map_uids = list()
 
 		for mx_id, mx_info in infos:
 			if 'Name' not in mx_info:
@@ -185,9 +190,7 @@ class MX(AppConfig):  # pragma: no cover
 				result = await self.instance.map_manager.add_map(map_filename, save_matchsettings=False)
 
 				if result:
-					# Juke if setting has been provided.
-					if juke_maps:
-						juke_list.append(mx_info['MapUID'])
+					added_map_uids.append(mx_info['MapUID'])
 
 					message = '$ff0Admin $fff{}$z$s$ff0 has added{} the map $fff{}$z$s$ff0 by $fff{}$z$s$ff0 from MX..'.format(
 						player.nickname, ' and juked' if juke_maps else '', mx_info['Name'], mx_info['Username']
@@ -213,9 +216,11 @@ class MX(AppConfig):  # pragma: no cover
 			pass
 
 		# Jukebox all the maps requested, in order.
-		if juke_maps and len(juke_list) > 0:
+		if juke_maps and len(added_map_uids) > 0:
 			# Fetch map objects.
-			for juke_uid in juke_list:
+			for juke_uid in added_map_uids:
 				map_instance = await self.instance.map_manager.get_map(uid=juke_uid)
 				if map_instance:
 					self.instance.apps.apps['jukebox'].insert_map(player, map_instance)
+
+		return [await self.instance.map_manager.get_map(uid=added_uid) for added_uid in added_map_uids]
